// ------------------------------------------------------------
// File:        gov_border.js
//
// Copyright:   (c) 2002 Darren John Dwyer, Sydney, Australia,
//              All Rights Reserved.
//
// ------------------------------------------------------------
// Border interface
//
// This file provides a simple to use full-screen border class
//
// ------------------------------------------------------------
// Example:
//        var border1 = new d_Border( "border1" );
//
//        border1.Hide();
//
//        border1.TopLeft = 'Images/Top_Left.gif';
//        border1.TopEdge = 'Images/Top_Edge.gif';
//        border1.TopRight = 'Images/Top_Right.gif';
//        border1.LeftEdge = 'Images/Left_Edge.gif';
//        border1.RightEdge = 'Images/Right_Edge.gif';
//        border1.BottomLeft = 'Images/Bottom_Left.gif';
//        border1.BottomEdge = 'Images/Bottom_Edge.gif';
//        border1.BottomRight = 'Images/Bottom_Right.gif';
//
//        border1.Show();
//
// ------------------------------------------------------------

// ------------------------------------------------------------
// Define Global Border Variables
// ------------------------------------------------------------

var     d_Border_Counter = 0;
var    d_Border_Debug = true;

// ------------------------------------------------------------
// Object Definition
// ------------------------------------------------------------

function d_Border( name )
{

    // ----------------------------------------------------
    // Properties
    // ----------------------------------------------------

    this.Name        = name;
    this.Type        = "d_Border";
    this.Id            = d_Border_Counter++;

    this.Target        = name;
    this.Loaded        = d_Border_Loaded;
    this.Visibility        = d_Border_Visibility;

    this.Top        = d_Border_Top;
    this.Left        = d_Border_Left;
    this.Right        = d_Border_Right;
    this.Bottom        = d_Border_Bottom;

    this.Width        = d_Border_Width;
    this.Height        = d_Border_Height;

    this.Style        = "";
    this.BorderStyle    = "";

    // ----------------------------------------------------
    // Methods
    // ----------------------------------------------------

    this.Show        = d_Border_Show;
    this.Hide        = d_Border_Hide;

    this.FadeIn        = d_Border_FadeIn;
    this.FadeOut        = d_Border_FadeOut;

    // ----------------------------------------------------
    // Events
    // ----------------------------------------------------

    // none

    // ----------------------------------------------------
    // Internal
    // ----------------------------------------------------

    this.Top_Left_Image    = null;
    this.Top_Edge_Image    = null;
    this.Top_Right_Image    = null;
    this.Left_Edge_Image    = null;
    this.Right_Edge_Image    = null;
    this.Bottom_Left_Image    = null;
    this.Bottom_Edge_Image    = null;
    this.Bottom_Right_Image    = null;

}

// ------------------------------------------------------------
// End of Object Definition
// ------------------------------------------------------------


// ------------------------------------------------------------
// Method Code
// ------------------------------------------------------------

// ------------------------------------------------------------

function d_Image_Show()
{
if (IE)     document.images[this.Target].style.visibility = "visible";
else        document[this.Target].style.visibility = "show";
}

// ------------------------------------------------------------

function d_Image_Hide()
{
if (IE)     document.images[this.Target].style.visibility = "hidden";
else         document[this.Target].style.visibility = "hide";
}

// ------------------------------------------------------------

function d_Image_FadeIn()
{
if (IE) 
    {
    document.images[this.Target].filters.item(0).Apply();
    document.images[this.Target].style.visibility = "visible";
    document.images[this.Target].filters.item(0).Play();
    }
else
    {
    document[this.Target].style.visibility = "show";
    }
}

// ------------------------------------------------------------

function d_Image_FadeOut()
{
if (IE) 
    {
    document.images[this.Target].filters.item(0).Apply();
    document.images[this.Target].style.visibility = "hidden";
    document.images[this.Target].filters.item(0).Play();
    }
else
    {
    document[this.Target].style.visibility = "hide";
    }
}

// ------------------------------------------------------------

function d_Image_MoveTo( x, y )
{
if (IE) 
    {
    document.images[this.Target].style.top = y;
    document.images[this.Target].style.left = x;
    }
else
    {
    document[this.Target].top = y;
    document[this.Target].left = x;
    }
}

// ------------------------------------------------------------

function d_Image_MoveBy( x, y )
{
var top = this.Top();
var left = this.Left();
if (IE) 
    {
    document.images[this.Target].style.top = top + y;
    document.images[this.Target].style.left = left + x;
    }
else
    {
    document[this.Target].top = top + y;
    document[this.Target].left = left + x;
    }
}

// ------------------------------------------------------------

function d_Image_GrowTo( x, y )
{
if (IE) 
    {
    document.images[this.Target].style.width = x;
    document.images[this.Target].style.height = y;
    }
else
    {
    document[this.Target].width = x;
    document[this.Target].height = y;
    }
}

// ------------------------------------------------------------

function d_Image_GrowBy( x, y )
{
var width = this.Width();
var height = this.Height();
if (IE) 
    {
    document.images[this.Target].style.width = width + x;
    document.images[this.Target].style.height = height + y;
    }
else
    {
    document[this.Target].width = width + x;
    document[this.Target].height = height + y;
    }
}

// ------------------------------------------------------------

function d_Image_LoadFromFile( file_name )
{
if (IE)        document.images[this.Target].src = file_name;
else        document[this.Target].src = file_name;
}

// ------------------------------------------------------------
