// ------------------------------------------------------------
// File:        gov_image.js
//
// Copyright:   (c) 2002 Darren John Dwyer, Sydney, Australia,
//              All Rights Reserved.
//
// ------------------------------------------------------------
// Image interface
//
// This file provides a simple to use image manipulation class
//
// ------------------------------------------------------------
// Example:
//        var image1 = new d_Image( "image1" );
//
//        for (i=0;i<100;i++) 
//            {
//            image1.Left = i;
//            image1.Width = i;
//            }
//
// ------------------------------------------------------------

// ------------------------------------------------------------
// Define Global Image Variables
// ------------------------------------------------------------

var     d_Image_Counter = 0;
var    d_Image_Debug = true;

// ------------------------------------------------------------
// Object Definition
// ------------------------------------------------------------

function d_Image( name )
{

    // ----------------------------------------------------
    // Properties
    // ----------------------------------------------------

    this.Name        = name;
    this.Type        = "d_Image";
    this.Id            = d_Image_Counter++;

    this.Target        = name;
    this.Loaded        = d_Image_Loaded;
    this.Visibility        = d_Image_Visibility;

    this.Top        = d_Image_Top;
    this.Left        = d_Image_Left;
    this.Right        = d_Image_Right;
    this.Bottom        = d_Image_Bottom;

    this.Width        = d_Image_Width;
    this.Height        = d_Image_Height;

    this.Style        = "";
    this.BorderStyle    = "";

    // ----------------------------------------------------
    // Methods
    // ----------------------------------------------------

    this.Show        = d_Image_Show;
    this.Hide        = d_Image_Hide;

    this.FadeIn        = d_Image_FadeIn;
    this.FadeOut        = d_Image_FadeOut;

    this.MoveTo        = d_Image_MoveTo;
    this.MoveBy        = d_Image_MoveBy;

    this.GrowTo        = d_Image_GrowTo;
    this.GrowBy        = d_Image_GrowBy;

    this.LoadFromFile    = d_Image_LoadFromFile;

    // ----------------------------------------------------
    // Events
    // ----------------------------------------------------

//    this.OnLoad        = d_Image_OnLoad;

    // ----------------------------------------------------
    // Internal
    // ----------------------------------------------------

    this.Image        = null;

}

// ------------------------------------------------------------
// End of Object Definition
// ------------------------------------------------------------


// ------------------------------------------------------------
// Method Code
// ------------------------------------------------------------

// ------------------------------------------------------------

function d_Image_Loaded()
{
return (IE)     ? document.images[this.Target].complete
        : document[this.Target].complete;
}

// ------------------------------------------------------------

function d_Image_Visibility()
{
return (IE)    ? document.images[this.Target].style.visibility
        : document[this.Target].style.visibility;
}

// ------------------------------------------------------------

function d_Image_Top()
{
return (IE)     ? document.images[this.Target].style.pixelTop
        : document[this.Target].top;
}

// ------------------------------------------------------------

function d_Image_Left()
{
return (IE)     ? document.images[this.Target].style.pixelLeft
        : document[this.Target].left;
}

// ------------------------------------------------------------

function d_Image_Right()
{
return (IE)     ? document.images[this.Target].style.pixelRight
        : document[this.Target].right;
}

// ------------------------------------------------------------

function d_Image_Bottom()
{
return (IE)     ? document.images[this.Target].style.pixelBottom
        : document[this.Target].bottom;
}

// ------------------------------------------------------------

function d_Image_Width()
{
return (IE)     ? document.images[this.Target].style.pixelWidth
        : document[this.Target].width;
}

// ------------------------------------------------------------

function d_Image_Height()
{
return (IE)     ? document.images[this.Target].style.pixelHeight
        : document[this.Target].height;
}

// ------------------------------------------------------------

function d_Image_Show()
{
if (IE)     document.images[this.Target].style.visibility = "visible";
else        document[this.Target].style.visibility = "show";
}

// ------------------------------------------------------------

function d_Image_Hide()
{
if (IE)     document.images[this.Target].style.visibility = "hidden";
else         document[this.Target].style.visibility = "hide";
}

// ------------------------------------------------------------

function d_Image_FadeIn()
{
if (IE) 
    {
    document.images[this.Target].filters.item(0).Apply();
    document.images[this.Target].style.visibility = "visible";
    document.images[this.Target].filters.item(0).Play();
    }
else
    {
    document[this.Target].style.visibility = "show";
    }
}

// ------------------------------------------------------------

function d_Image_FadeOut()
{
if (IE) 
    {
    document.images[this.Target].filters.item(0).Apply();
    document.images[this.Target].style.visibility = "hidden";
    document.images[this.Target].filters.item(0).Play();
    }
else
    {
    document[this.Target].style.visibility = "hide";
    }
}

// ------------------------------------------------------------

function d_Image_MoveTo( x, y )
{
if (IE) 
    {
    document.images[this.Target].style.top = y;
    document.images[this.Target].style.left = x;
    }
else
    {
    document[this.Target].top = y;
    document[this.Target].left = x;
    }
}

// ------------------------------------------------------------

function d_Image_MoveBy( x, y )
{
var top = this.Top();
var left = this.Left();
if (IE) 
    {
    document.images[this.Target].style.top = top + y;
    document.images[this.Target].style.left = left + x;
    }
else
    {
    document[this.Target].top = top + y;
    document[this.Target].left = left + x;
    }
}

// ------------------------------------------------------------

function d_Image_GrowTo( x, y )
{
if (IE) 
    {
    document.images[this.Target].style.width = x;
    document.images[this.Target].style.height = y;
    }
else
    {
    document[this.Target].width = x;
    document[this.Target].height = y;
    }
}

// ------------------------------------------------------------

function d_Image_GrowBy( x, y )
{
var width = this.Width();
var height = this.Height();
if (IE) 
    {
    document.images[this.Target].style.width = width + x;
    document.images[this.Target].style.height = height + y;
    }
else
    {
    document[this.Target].width = width + x;
    document[this.Target].height = height + y;
    }
}

// ------------------------------------------------------------

function d_Image_LoadFromFile( file_name )
{
if (IE)        document.images[this.Target].src = file_name;
else        document[this.Target].src = file_name;
}

// ------------------------------------------------------------
