// ------------------------------------------------------------
// File:        gov_screen.js
//
// Copyright:   (c) 2002 Darren John Dwyer, Sydney, Australia,
//              All Rights Reserved.
//
// ------------------------------------------------------------
// Screen interface
//
// This file provides a simple to use video display interface
//
// ------------------------------------------------------------
// Example:
//        var screen1 = new Screen();
//
//        screen1.Name = "screen1";
//        screen1.OnResize = ResizeEntireDisplay();
//        screen1.OnLoad = FadeIn();
//
// ------------------------------------------------------------

// ------------------------------------------------------------
// Define Global Timer Variables
// ------------------------------------------------------------

var     Timer_Counter = 0;
var    Timer_Debug = true;

// ------------------------------------------------------------
// Object Definition
// ------------------------------------------------------------

function Timer()
{

    // ----------------------------------------------------
    // Properties
    // ----------------------------------------------------

    this.Name        = "timer"+(++Timer_Counter);    // eg. Timer1, Timer2, Timer3, etc.
    this.Type         = "Timer";            // type of class
    this.Interval        = 1;                // anywhere 0..N,  >0 == ok,  0==ie5 and netscape hindrance boxes... 
    this.TimeOut        = 100;                // total number of times to call Tick() method
    this.Active        = false;            // see: example above
    this.Paused        = false;            // if true, Tick() does nothing. no timer ticking.
    this.TickCount        = 0;                // total # of timer Tick() has been called

    // ----------------------------------------------------
    // Methods
    // ----------------------------------------------------

    this.Start         = Timer_Start;            // sets a timer to call the Tick() function
    this.Stop         = Timer_Stop;            // stops the timer which calls the Tick() function

    this.Pause        = Timer_Pause;            // don't do anything in Tick()
    this.Resume        = Timer_Resume;            // continue calling Tick()

    this.Reset        = Timer_Reset;            // this.TickCount=0

    this.Tick        = Timer_Tick;            // called on each tick of the timer

    // ----------------------------------------------------
    // Events
    // ----------------------------------------------------

    this.OnStart        = Timer_OnStart;        // re-assign to your own code. eg. timer1.OnStart = MyFunction
    this.OnStop        = Timer_OnStop;            // your function is called whenever Start() works correctly.
    this.OnTick        = Timer_OnTick;            
    this.OnPause        = Timer_OnPause;
    this.OnResume        = Timer_OnResume;

    // ----------------------------------------------------
    // Internal
    // ----------------------------------------------------

    this.Timer        = null;

}

// ------------------------------------------------------------
// End of Object Definition
// ------------------------------------------------------------


// ------------------------------------------------------------
// Method Code
// ------------------------------------------------------------

// ------------------------------------------------------------

function Timer_Start()
{
if (!this.Active)
    {
    this.OnStart();
    this.Timer = setInterval( this.Name + ".Tick()", this.Interval );
    this.Active = true;
    }
}

// ------------------------------------------------------------

function Timer_Stop()
{
if (this.Active)
    {
    clearInterval( this.Timer );
    this.Active = false;
    this.OnStop();
    }
}

// ------------------------------------------------------------

function Timer_Pause()
{
if (this.Active)
    {
    clearInterval( this.Timer );
    this.Paused = true;
    this.OnPause();
    }
}

// ------------------------------------------------------------

function Timer_Resume()
{
if (this.Paused)
    {
    this.OnResume();
    this.Timer = setInterval( this.Name + ".Tick()", this.Interval );
    this.Paused = false;
    }
}

// ------------------------------------------------------------

function Timer_Reset()
{
this.TickCount = 0;
}

// ------------------------------------------------------------

function Timer_Tick()
{
status = this.Name+"::Tick(), count=="+this.TickCount;
if (this.Active)
    {
    this.OnTick();
    this.TickCount++;
    if (this.TickCount > this.TimeOut) this.Stop();
    }
return true;
}

// ------------------------------------------------------------


// ------------------------------------------------------------
// Default Event Handling Code
// ------------------------------------------------------------

function Timer_OnStart()
{
if (Timer_Debug) status = "Note: "+this.Name+"::OnStart()";
}

// ------------------------------------------------------------

function Timer_OnStop()
{
if (Timer_Debug) status = "Note: "+this.Name+"::OnStop()";
}

// ------------------------------------------------------------

function Timer_OnPause()
{
if (Timer_Debug) status = "Note: "+this.Name+"::OnPause()";
}

// ------------------------------------------------------------

function Timer_OnResume()
{
if (Timer_Debug) status = "Note: "+this.Name+"::OnResume()";
}

// ------------------------------------------------------------

function Timer_OnTick()
{
if (Timer_Debug) status = "Note: "+this.Name+"::OnTick(), count=="+this.TickCount;
}

// ------------------------------------------------------------
