// ------------------------------------------------------------
// File:        gov_text.js
//
// Copyright:   (c) 2002 Darren John Dwyer, Sydney, Australia,
//              All Rights Reserved.
//
// ------------------------------------------------------------
// text interface
//
// This file provides a simple to use text manipulation class
//
// ------------------------------------------------------------
// Example:
//        var text1 = new d_Text( "text1" );
//
//        for (i=0;i<100;i++) 
//            {
//            text1.MoveTo( 0, i );
//            }
//
// ------------------------------------------------------------

// ------------------------------------------------------------
// Define Global Text Variables
// ------------------------------------------------------------

var     d_Text_Counter = 0;
var    d_Text_Debug = true;

// ------------------------------------------------------------
// Object Definition
// ------------------------------------------------------------

function d_Text( name )
{

    // ----------------------------------------------------
    // Properties
    // ----------------------------------------------------

    this.Name        = name;
    this.Type        = "d_Text";
    this.Id            = d_Text_Counter++;

    this.Target        = name;
    this.Visibility        = d_Text_Visibility;

    this.Top        = d_Text_Top;
    this.Left        = d_Text_Left;
    this.Right        = d_Text_Right;
    this.Bottom        = d_Text_Bottom;

    this.Width        = d_Text_Width;
    this.Height        = d_Text_Height;

    this.Style        = "";
    this.BorderStyle    = "";

    // ----------------------------------------------------
    // Methods
    // ----------------------------------------------------

    this.Hide        = d_Text_Hide;
    this.Show        = d_Text_Show;

    this.FadeIn        = d_Text_FadeIn;
    this.FadeOut        = d_Text_FadeOut;

    this.MoveTo        = d_Text_MoveTo;
    this.MoveBy        = d_Text_MoveBy;

    this.GrowTo        = d_Text_GrowTo;
    this.GrowBy        = d_Text_GrowBy;

    this.SetText        = d_Text_SetText;
    this.SetHTML        = d_Text_SetHTML;

//    this.LoadFromFile    = d_Text_LoadFromFile;

    // ----------------------------------------------------
    // Events
    // ----------------------------------------------------

//    this.OnLoad        = d_Text_OnLoad;

    // ----------------------------------------------------
    // Internal
    // ----------------------------------------------------

    this.Text        = "";
    this.HTML        = "";

}

// ------------------------------------------------------------
// End of Object Definition
// ------------------------------------------------------------


// ------------------------------------------------------------
// Method Code
// ------------------------------------------------------------

// ------------------------------------------------------------

function d_Text_Visibility()
{
return (IE)    ? document.all[this.Target].style.visibility
        : document[this.Target].style.visibility;
}

// ------------------------------------------------------------

function d_Text_Top()
{
return (IE)     ? document.all[this.Target].style.pixelTop
        : document[this.Target].top;
}

// ------------------------------------------------------------

function d_Text_Left()
{
return (IE)     ? document.all[this.Target].style.pixelLeft
        : document[this.Target].left;
}

// ------------------------------------------------------------

function d_Text_Right()
{
return (IE)     ? document.all[this.Target].style.pixelRight
        : document[this.Target].right;
}

// ------------------------------------------------------------

function d_Text_Bottom()
{
return (IE)     ? document.all[this.Target].style.pixelBottom
        : document[this.Target].bottom;
}

// ------------------------------------------------------------

function d_Text_Width()
{
return (IE)     ? document.all[this.Target].style.pixelWidth
        : document[this.Target].width;
}

// ------------------------------------------------------------

function d_Text_Height()
{
return (IE)     ? document.all[this.Target].style.pixelHeight
        : document[this.Target].height;
}

// ------------------------------------------------------------

function d_Text_Show()
{
if (IE)     document.all[this.Target].style.visibility = "visible";
else        document[this.Target].style.visibility = "show";
}

// ------------------------------------------------------------

function d_Text_Hide()
{
if (IE)     document.all[this.Target].style.visibility = "hidden";
else        document[this.Target].style.visibility = "hide";
}

// ------------------------------------------------------------

function d_Text_FadeIn()
{
if (IE)     document.all[this.Target].style.visibility = "visible";
else        document[this.Target].style.visibility = "show";
}

// ------------------------------------------------------------

function d_Text_FadeOut()
{
if (IE)     document.all[this.Target].style.visibility = "hidden";
else        document[this.Target].style.visibility = "hide";
}

// ------------------------------------------------------------

function d_Text_MoveTo( x, y )
{
if (IE)     {
        document.all[this.Target].style.top = y;
        document.all[this.Target].style.left = x;
        }
else        {
        document.all[this.Target].style.pixelTop = y;
        document.all[this.Target].style.pixelLeft = x;
        }
}

// ------------------------------------------------------------

function d_Text_MoveBy( x, y )
{
var top = this.Top();
var left = this.Left();

if (IE)     {
        document.all[this.Target].style.top = top + y;
        document.all[this.Target].style.left = left + x;
        }
else        {
        document[this.Target].top = top + y;
        document[this.Target].left = left + x;
        }
}

// ------------------------------------------------------------

function d_Text_GrowTo( x, y )
{
if (IE) 
    {
    document.all[this.Target].style.width = x;
    document.all[this.Target].style.height = y;
    }
else
    {
    document[this.Target].width = x;
    document[this.Target].height = y;
    }
}

// ------------------------------------------------------------

function d_Text_GrowBy( x, y )
{
var width = this.Width();
var height = this.Height();
if (IE) 
    {
    document.all[this.Target].style.width = width + x;
    document.all[this.Target].style.height = height + y;
    }
else
    {
    document[this.Target].width = width + x;
    document[this.Target].height = height + y;
    }
}

// ------------------------------------------------------------

function d_Text_SetText( text )
{
this.Text = text;

if (IE)     document.all[this.Target].innerText = this.Text;
else         document[this.Target].innerText = this.Text;
}

// ------------------------------------------------------------

function d_Text_SetHTML( html )
{
this.HTML = html;

if (IE)     document.all[this.Target].innerHTML = this.HTML;
else         document[this.Target].innerHTML = this.HTML;
}

// ------------------------------------------------------------

function d_text_LoadFromFile( file_name )
{
this.src = file_name;
}

// ------------------------------------------------------------
